summaryrefslogtreecommitdiffstats
path: root/qt/qextscintillabase.h
diff options
context:
space:
mode:
authorTimothy Pearson <[email protected]>2011-11-30 12:33:18 -0600
committerTimothy Pearson <[email protected]>2011-11-30 12:33:18 -0600
commit03bc485016127d419bbbbc3cfb09e21e8754b383 (patch)
treecad8234bcf26063239ac7a565298b897ffdeef57 /qt/qextscintillabase.h
parent664e37abfe5c796c1279b8295fb030f126b0a7d8 (diff)
downloadtqscintilla-03bc485016127d419bbbbc3cfb09e21e8754b383.tar.gz
tqscintilla-03bc485016127d419bbbbc3cfb09e21e8754b383.zip
Initial automated TQt conversion
Diffstat (limited to 'qt/qextscintillabase.h')
-rw-r--r--qt/qextscintillabase.h105
1 files changed, 53 insertions, 52 deletions
diff --git a/qt/qextscintillabase.h b/qt/qextscintillabase.h
index 80222e5..2bf2092 100644
--- a/qt/qextscintillabase.h
+++ b/qt/qextscintillabase.h
@@ -3,40 +3,40 @@
// Copyright (c) 2006
// Riverbank Computing Limited <[email protected]>
//
-// This file is part of QScintilla.
+// This file is part of TQScintilla.
//
-// This copy of QScintilla is free software; you can redistribute it and/or
+// This copy of TQScintilla is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2, or (at your option) any
// later version.
//
-// QScintilla is supplied in the hope that it will be useful, but WITHOUT ANY
+// TQScintilla is supplied in the hope that it will be useful, but WITHOUT ANY
// WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
// FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
// details.
//
// You should have received a copy of the GNU General Public License along with
-// QScintilla; see the file LICENSE. If not, write to the Free Software
+// TQScintilla; see the file LICENSE. If not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
-#ifndef QEXTSCINTILLABASE_H
-#define QEXTSCINTILLABASE_H
+#ifndef TQEXTSCINTILLABASE_H
+#define TQEXTSCINTILLABASE_H
-#include <qobject.h>
-#include <qpoint.h>
-#include <qtimer.h>
-#include <qwidget.h>
+#include <tqobject.h>
+#include <tqpoint.h>
+#include <tqtimer.h>
+#include <tqwidget.h>
-#include <qextscintillaglobal.h>
+#include <tqextscintillaglobal.h>
-class ScintillaQt;
-class QScrollBar;
-class QColor;
-class QPainter;
-class QPixmap;
+class ScintillaTQt;
+class TQScrollBar;
+class TQColor;
+class TQPainter;
+class TQPixmap;
//! \brief The QextScintillaBase class implements the Scintilla editor widget
@@ -47,15 +47,16 @@ class QPixmap;
//! completion and call tips. It is particularly useful as a programmer's
//! editor.
//!
//! QextScintillaBase is a port to Qt of Scintilla. It implements the standard
//! Scintilla API which consists of a number of messages each taking up to
//! two arguments.
//!
//! See QextScintilla for the implementation of a higher level API that is more
-//! consistent with the rest of the Qt toolkit.
-class QEXTSCINTILLA_EXPORT QextScintillaBase : public QWidget
+//! consistent with the rest of the TQt toolkit.
+class TQEXTSCINTILLA_EXPORT QextScintillaBase : public TQWidget
{
Q_OBJECT
+ TQ_OBJECT
public:
//! The low-level Scintilla API is implemented as a set of messages
@@ -301,7 +302,7 @@ public:
//! markers to a pixmap. Pixmaps use the SC_MARK_PIXMAP marker
//! symbol.
//! \a wParam is the number of the marker.
//! \a lParam is a pointer to a QPixmap instance. Note that in
//! other ports of Scintilla this is a pointer to either raw or
//! textual XPM image data.
//!
@@ -1290,7 +1291,7 @@ public:
//! This message takes a copy of an image and registers it so
//! that it can be refered to by a unique integer identifier.
//! \a wParam is the image's identifier.
//! \a lParam is a pointer to a QPixmap instance. Note that in
//! other ports of Scintilla this is a pointer to either raw or
//! textual XPM image data.
//!
@@ -1772,7 +1773,7 @@ public:
{
INDIC_MAX = 7,
INDIC_PLAIN = 0,
- INDIC_SQUIGGLE = 1,
+ INDIC_STQUIGGLE = 1,
INDIC_TT = 2,
INDIC_DIAGONAL = 3,
INDIC_STRIKE = 4,
@@ -2171,7 +2172,7 @@ public:
//! Construct an empty QextScintillaBase with parent \a parent, name
//! \a name, and widget flags \a f.
- QextScintillaBase(QWidget *parent = 0,const char *name = 0,
+ QextScintillaBase(TQWidget *parent = 0,const char *name = 0,
WFlags f = 0);
//! Destroys the QextScintillaBase instance.
@@ -2225,34 +2226,34 @@ public:
//! \overload
long SendScintilla(unsigned int msg,unsigned long wParam,
- const QColor &col);
+ const TQColor &col);
//! \overload
- long SendScintilla(unsigned int msg,const QColor &col);
+ long SendScintilla(unsigned int msg,const TQColor &col);
//! \overload
- long SendScintilla(unsigned int msg,unsigned long wParam,QPainter *hdc,
- const QRect &rc,long cpMin,long cpMax);
+ long SendScintilla(unsigned int msg,unsigned long wParam,TQPainter *hdc,
+ const TQRect &rc,long cpMin,long cpMax);
//! \overload
long SendScintilla(unsigned int msg,unsigned long wParam,
- const QPixmap *lParam)
+ const TQPixmap *lParam)
{
return SendScintilla(msg,wParam,reinterpret_cast<long>(lParam));
}
//! Returns the recommended size of the widget.
- virtual QSize sizeHint() const;
+ virtual TQSize tqsizeHint() const;
//! Returns the viewport widget. This is the widget that actually
//! contains the text.
- QWidget *viewport() const;
+ TQWidget *viewport() const;
signals:
//! This signal is emitted when text is selected or de-selected.
//! \a yes is TRUE if text has been selected and FALSE if text has been
//! deselected.
- void QSCN_SELCHANGED(bool yes);
+ void TQSCN_SELCHANGED(bool yes);
//! This signal is emitted when the user selects an item in an
//! auto-completion list. It is emitted before the selection is
@@ -2363,16 +2364,16 @@ signals:
protected:
//! Re-implemented to filter certain events.
- bool eventFilter(QObject *o,QEvent *e);
+ bool eventFilter(TQObject *o,TQEvent *e);
//! Re-implemented to handle the key presses for the widget.
- virtual void keyPressEvent(QKeyEvent *ke);
+ virtual void keyPressEvent(TQKeyEvent *ke);
//! Re-implemented to tell Scintilla it has the focus.
- virtual void focusInEvent(QFocusEvent *);
+ virtual void focusInEvent(TQFocusEvent *);
//! Re-implemented to tell Scintilla it has lost the focus.
- virtual void focusOutEvent(QFocusEvent *);
+ virtual void focusOutEvent(TQFocusEvent *);
//! Re-implemented to allow tabs to be entered as text.
virtual bool focusNextPrevChild(bool);
@@ -2388,23 +2389,23 @@ private slots:
void handleSelection();
private:
- friend class ScintillaQt;
-
- void mousePress(QMouseEvent *me);
- void mouseRelease(QMouseEvent *me);
- void mouseDoubleClick(QMouseEvent *me);
- void mouseMove(QMouseEvent *me);
- void mouseWheel(QWheelEvent *we);
- void contextMenu(QContextMenuEvent *cme);
-
- ScintillaQt *sci;
- QPoint triple_click_at;
- QTimer triple_click;
- QScrollBar *vsb;
- QScrollBar *hsb;
- QWidget *txtarea;
-
-#if defined(Q_DISABLE_COPY)
+ friend class ScintillaTQt;
+
+ void mousePress(TQMouseEvent *me);
+ void mouseRelease(TQMouseEvent *me);
+ void mouseDoubleClick(TQMouseEvent *me);
+ void mouseMove(TQMouseEvent *me);
+ void mouseWheel(TQWheelEvent *we);
+ void contextMenu(TQContextMenuEvent *cme);
+
+ ScintillaTQt *sci;
+ TQPoint triple_click_at;
+ TQTimer triple_click;
+ TQScrollBar *vsb;
+ TQScrollBar *hsb;
+ TQWidget *txtarea;
+
+#if defined(TQ_DISABLE_COPY)
QextScintillaBase(const QextScintillaBase &);
QextScintillaBase &operator=(const QextScintillaBase &);
#endif
@@ -47,15 +47,16 @@ class QPixmap;
//! editor.
//!
-//! QextScintillaBase is a port to Qt of Scintilla. It implements the standard
+//! QextScintillaBase is a port to TQt of Scintilla. It implements the standard
//! Scintilla API which consists of a number of messages each taking up to
//! two arguments.
@@ -301,7 +302,7 @@ public:
//! symbol.
//! \a wParam is the number of the marker.
- //! \a lParam is a pointer to a QPixmap instance. Note that in
+ //! \a lParam is a pointer to a TQPixmap instance. Note that in
//! other ports of Scintilla this is a pointer to either raw or
//! textual XPM image data.
@@ -1290,7 +1291,7 @@ public:
//! that it can be refered to by a unique integer identifier.
//! \a wParam is the image's identifier.
- //! \a lParam is a pointer to a QPixmap instance. Note that in
+ //! \a lParam is a pointer to a TQPixmap instance. Note that in
//! other ports of Scintilla this is a pointer to either raw or
//! textual XPM image data.